#!/usr/bin/perl -w
#
# Convert RRDs created on a 32bit OS to 64bit
#

use strict;
use File::Basename;

my $dir   = '/var/www/fci/';
my $tmp   = '/tmp/';
my $host  = 'fci-server.example.com';
my %files = ();

# convert the 32bit RRDs to XML
print "Dumping RRD files to XML:\n";

foreach my $rrd (`find $dir -name *.rrd -print`) {
	chomp($rrd);

	my $base = basename($rrd);
	my $xml  = $tmp . $base .'.xml';

	my $cmd = 'rrdtool dump '. $rrd .' '. $xml;

	print "Exec: $cmd\n";
	my $exit = system($cmd) >> 8;
	print "Exit: $exit\n";

	if($exit == 0) {
		$files{$base}{rrd} = $rrd;
		$files{$base}{xml} = $xml;
	}
}

# copy the XML files to the remote host
if(keys %files > 0) {
	print "Copying XML files to remote host:\n";

	my $cmd = 'scp ';
	foreach my $base (sort keys %files) {
		$cmd .= $files{$base}{xml} .' ';
	}
	$cmd .= $host .':'. $tmp;

	print "Exec: $cmd\n";
	my $exit = system($cmd) >> 8;
	print "Exit: $exit\n";

	if($exit == 0) {
		# Restore the RRD files from XML on the remote host

		my $remote_cmd = '';
		my $i = 0;
		foreach my $base (sort keys %files) {
			$i++;

			my $restore_cmd = 'rrdtool restore '. $files{$base}{xml} .' '. $files{$base}{rrd} .' -f && rm '. $files{$base}{xml};

			$remote_cmd .= $restore_cmd;
			$remote_cmd .= ' && ' if($remote_cmd ne '' && $i < keys %files);
		}

		my $cmd = 'ssh '. $host .' "'. $remote_cmd .'"';

		print "Exec: $cmd\n";
		my $exit = system($cmd) >> 8;
		print "Exit: $exit\n";
	}
}
